package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`\P`!````>!\```````!``````````-BA````
M````!0```$``.``*`$``&@`9``8````$````0`````````!``````````$``
M````````,`(````````P`@````````@``````````P````0```!P`@``````
M`'`"````````<`(````````A`````````"$``````````0`````````#``!P
M!````&Z@`````````````````````````````&8````````````````````!
M``````````$````%````````````````````````````````````^)4`````
M``#XE0`````````0`````````0````8```"@FP```````*"K````````H*L`
M``````"P!````````-@$`````````!`````````"````!@```+B;````````
MN*L```````"XJP```````!`"````````$`(````````(``````````0````$
M````E`(```````"4`@```````)0"````````1`````````!$``````````0`
M````````4.5T9`0```#`C@```````,".````````P(X```````#L````````
M`.P`````````!`````````!1Y71D!@``````````````````````````````
M```````````````````````````0`````````%+E=&0$````H)L```````"@
MJP```````*"K````````8`0```````!@!`````````$`````````+VQI8B]L
M9"UL:6YU>"UR:7-C=C8T+6QP-C1D+G-O+C$`````!````!0````#````1TY5
M`.*M;=02K/8.S5+_<.R*MTL3-]"T!````!`````!````1TY5```````$````
M#P`````````1````1@````0````(````()`0`05`!,0H`@$$@(8$A(*)``()
M(`0(B(`00;H``H@`````1@```$D```!,````30```%4```!6````6````%H`
M``!;````7````%X```!@````80```&,``````````````&[%WQ_.WD<M:W^:
M?"[%F[;49-1\(?_D#MEQ6!SB1\8!L@&+;ZQ+X\!"^M>'PN4_++KCDGSZH6Q@
MF4_#FVL)0]9FK\QF&7X*AT)%U>R)!W#3<U"?V#-BV^T^S])L%8PES`PZEPO_
M8?)A?ZF<F^"G`@IK&IY0H^#[20``````````````````````````````````
M`````````P`,`/`=``````````````````#4`@``$0``````````````````
M``````#5````$@````````````````````````#-`0``$@``````````````
M``````````"P`@``$@````````````````````````"'````$@``````````
M``````````````!.`0``$@````````````````````````"#`@``$@``````
M``````````````````#4`0``$@````````````````````````!E`0``$@``
M``````````````````````"5`0``$@````````````````````````#K````
M$@````````````````````````"?`@``$@````````````````````````"Z
M`@``$0````````````````````````"*`@``$@``````````````````````
M``"(`0``$@`````````````````````````<`0``$@``````````````````
M```````,`0``$@````````````````````````#^````$@``````````````
M``````````#L`0``$@````````````````````````#;`0``$@``````````
M``````````````"^`0``$@````````````````````````#"`@``$@``````
M```````````````````!````(``````````````````````````"`@``$@``
M``````````````````````!L`0``$@`````````````````````````=````
M(``````````````````````````P`@``$@````````````````````````"F
M`0``$@`````````````````````````W````$@``````````````````````
M``"1`@``$@````````````````````````"X`@``$0``````````````````
M``````!4````%@````````````````````````#[`0``$@``````````````
M```````````^`0``$@````````````````````````"8`@``$@``````````
M``````````````!G````$@````````````````````````!M`@``$@``````
M``````````````````#$````$@````````````````````````!X````$@``
M``````````````````````"-`0``$@````````````````````````"H````
M$@````````````````````````#:````$@````````````````````````#%
M`0``$@````````````````````````!F`@``$@``````````````````````
M``#F`0``$@`````````````````````````P`0``$@``````````````````
M``````"?`0``$@````````````````````````!0`@``$@``````````````
M``````````!)`@``$0````````````````````````#?````$@``````````
M``````````````"V`0``$@`````````````````````````O`@``$@``````
M``````````````````!7`@``(@````````````````````````"3````$@``
M```````````````````````+`@``$@````````````````````````#A`0``
M$@````````````````````````!T`@``$@````````````````````````!9
M`0``$@`````````````````````````A`@``$@``````````````````````
M``"<`P``$@````````````````````````"W````$0``````````````````
M```````3`@``$@`````````````````````````E`0``$@``````````````
M``````````!%````$@`````````````````````````W`@``$@``````````
M``````````````![`@``$@````````````````````````!W`0``$@``````
M``````````````````"O`0``$@````````````````````````"E`P``$@`,
M`/HT````````I``````````W!```$@`,`((N````````R@0```````!$`@``
M$@`,`/`=````````B`$````````<`P``$@`,`/(E`````````@`````````Z
M`P``$@`,`$PS````````K@$```````!=!```$@`,`/0E````````I@$`````
M```=!```$``6`%"P```````````````````M`P``$@`,`)HG````````(@``
M``````!0`P``$@`,`!PL````````3@````````"]`P``$0`-`$A-````````
M!`````````#Z`P``$@`,`)1*````````]``````````5!```$@`,`!XE````
M````*``````````R!```$``6`'BP``````````````````!+!```$@`,`,(M
M````````P`````````!T!```$@`,`&HL````````2`````````#,`P``$``5
M``"P``````````````````!T`P``$@`,`+PG````````X`````````#H`P``
M$`#Q_P"X``````````````````!$!```$``5`%"P``````````````````!J
M!```$0`5`$BP````````"``````````%!```$``5`%"P````````````````
M``#2`P``$@`,`'@?````````(@````````#9`P``$``5``"P````````````
M```````I!```$@`,`#Y*````````5@````````#.`P``(``5``"P````````
M``````````"Q`P``$``6`'BP``````````````````"*`P``$@`,`*PM````
M````%@````````!>`P``$@`,`$8E````````K`````````"``P``$@`,`(A+
M````````M`$```````!\!```$@`,`)PH````````@`,`````````7TE435]D
M97)E9VES=&5R5$U#;&]N951A8FQE`%])5$U?<F5G:7-T97)434-L;VYE5&%B
M;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!03%]C=7)R96YT7V-O
M;G1E>'0`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V=E
M=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7W-V7W-E='!V;@!03%]D
M;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!P97)L7V9R964`4&5R;%]M9U]S
M970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F
M971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!B;V]T
M7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R
M;%]A;&QO8P!?7W-T86-K7V-H:U]F86EL`&5X:70`;'-E96LV-`!R96%D9&ER
M-C0`<W1R9'5P`&-L;W-E9&ER`&]P96XV-`!S=')R8VAR`'5N;&EN:P!M96UM
M;W9E`'-T<G1O:P!S=')L96X`<FUD:7(`<F5A9`!M:V1I<@!?7W9F<')I;G1F
M7V-H:P!G971P:60`<F5A9&QI;FL`<F5A;&QO8P!?7W-P<FEN=&9?8VAK`%]?
M9G!R:6YT9E]C:&L`;'-T870V-`!?7VQI8F-?<W1A<G1?;6%I;@!S=&1E<G(`
M;65M8VAR`%]?8WAA7V9I;F%L:7IE`'-T<F-H<@!M96UC;7``;65M<V5T`&]P
M96YD:7(`9V5T=6ED`&%C8V5S<P!M96UC<'D`<W1R8VUP`%]?97)R;F]?;&]C
M871I;VX`<W1R;F-M<`!?7V5N=FER;VX`7U]R96=I<W1E<E]A=&9O<FL`7U]S
M=&%C:U]C:&M?9W5A<F0`;&EB<&5R;"YS;RXU+C0P`&QI8F,N<V\N-@!L9"UL
M:6YU>"UR:7-C=C8T+6QP-C1D+G-O+C$`<&%R7V-U<G)E;G1?97AE8P!P87)?
M8F%S96YA;64`6%-?26YT97)N86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`
M<&%R7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]D:7)N86UE`'-H85]F:6YA;`!G
M971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!?7T)34U]%
M3D1?7P!?24]?<W1D:6Y?=7-E9`!?7V1A=&%?<W1A<G0`7U]$051!7T)%1TE.
M7U\`7U]G;&]B86Q?<&]I;G1E<B0`<VAA7W5P9&%T90!?7U-$051!7T)%1TE.
M7U\`>'-?:6YI=`!?7V)S<U]S=&%R=`!S:&%?:6YI=`!?96YD`'!A<E]M:W1M
M<&1I<@!?961A=&$`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V9I;F1P<F]G`&UY
M7W!A<E]P;`!P87)?9&EE`'!A<E]I;FET7V5N=@!'3$E"0U\R+C,T`$=,24)#
M7S(N,S,`1TQ)0D-?,BXR-P```````@`!``,``P`!``$``P`#``,``P`!``,`
M`P`#``,``0`!``$``P`#``,``P`!``,``0`!``0``P`!``,``P`!``,``0`#
M``$``P`!``$``P`!``,``P`#``,``0`#``,``P`!``,`!``#``$``P`#``,`
M`0`#``,``0`#``$``0`%``,``P`#``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``````````$`
M`P#V`@``$````$````"TD98&```%`(D$```0````LY&6!@``!`"4!```$```
M`(>1E@8```,`GP0````````!``$```,``!``````````AY&6!@```@"?!```
M`````*"K`````````P````````":'P```````*BK`````````P`````````L
M(````````+"K`````````P````````#T'P```````/BO`````````P``````
M``#P'0````````"P`````````P``````````L````````!BP`````````P``
M``````"H3@```````""P`````````P`````````040```````"BP````````
M`P`````````840```````#"P`````````P`````````@40```````#BP````
M`````P`````````H40```````$BP`````````P`````````P40```````*"O
M`````````@````(``````````````*BO`````````@````P`````````````
M`+"O`````````@````X``````````````+BO`````````@```!@`````````
M`````,"O`````````@```!L``````````````,BO````````"P```"$`````
M`````````-"O`````````@```",``````````````-BO`````````@```"4`
M`````````````."O`````````@```#(``````````````.BO`````````@``
M`#8``````````````/"O`````````@```#X``````````````-BM````````
M!0````,``````````````."M````````!0````0``````````````.BM````
M````!0````4``````````````/"M````````!0````8``````````````/BM
M````````!0````<```````````````"N````````!0````@`````````````
M``BN````````!0````D``````````````!"N````````!0````H`````````
M`````!BN````````!0````L``````````````""N````````!0````T`````
M`````````"BN````````!0````\``````````````#"N````````!0```!``
M`````````````#BN````````!0```!$``````````````$"N````````!0``
M`!(``````````````$BN````````!0```!,``````````````%"N````````
M!0```!0``````````````%BN````````!0```!4``````````````&"N````
M````!0```!8``````````````&BN````````!0```!<``````````````'"N
M````````!0```!D``````````````'BN````````!0```!H`````````````
M`("N````````!0```!P``````````````(BN````````!0```!T`````````
M`````)"N````````!0```!X``````````````)BN````````!0```!\`````
M`````````*"N````````!0```"(``````````````*BN````````!0```"0`
M`````````````+"N````````!0```"8``````````````+BN````````!0``
M`"<``````````````,"N````````!0```"@``````````````,BN````````
M!0```"D``````````````-"N````````!0```"H``````````````-BN````
M````!0```"L``````````````."N````````!0```"P``````````````.BN
M````````!0```"T``````````````/"N````````!0```"X`````````````
M`/BN````````!0```"\```````````````"O````````!0```#``````````
M``````BO````````!0```#$``````````````!"O````````!0```#,`````
M`````````!BO````````!0```#0``````````````""O````````!0```#4`
M`````````````"BO````````!0```#<``````````````#"O````````!0``
M`#@``````````````#BO````````!0```#D``````````````$"O````````
M!0```#H``````````````$BO````````!0```#L``````````````%"O````
M````!0```#P``````````````%BO````````!0```#T``````````````&"O
M````````!0```#\``````````````&BO````````!0```$``````````````
M`'"O````````!0```$$``````````````'BO````````!0```$(`````````
M`````("O````````!0```$,``````````````(BO````````!0```$0`````
M`````````)"O````````!0```$4``````````````)>3```S`\-!`[Z#-Q,#
M0_V3@H,W$U,3`(.R@@!G``X`%YX```,^CC9G`PX`$P```!>>```#/@XV9P,.
M`!,````7G@```SZ.-6<##@`3````%YX```,^#C5G`PX`$P```!>>```#/HXT
M9P,.`!,````7G@```SX.-&<##@`3````%YX```,^CC-G`PX`$P```!>>```#
M/@XS9P,.`!,````7G@```SZ.,F<##@`3````%YX```,^#C)G`PX`$P```!>>
M```#/HXQ9P,.`!,````7G@```SX.,6<##@`3````%YX```,^CC!G`PX`$P``
M`!>>```#/@XP9P,.`!,````7G@```SZ.+V<##@`3````%YX```,^#B]G`PX`
M$P```!>>```#/HXN9P,.`!,````7G@```SX.+F<##@`3````%YX```,^CBUG
M`PX`$P```!>>```#/@XM9P,.`!,````7G@```SZ.+&<##@`3````%YX```,^
M#BQG`PX`$P```!>>```#/HXK9P,.`!,````7G@```SX.*V<##@`3````%YX`
M``,^CBIG`PX`$P```!>>```#/@XJ9P,.`!,````7G@```SZ.*6<##@`3````
M%YX```,^#BEG`PX`$P```!>>```#/HXH9P,.`!,````7G@```SX.*&<##@`3
M````%YX```,^CB=G`PX`$P```!>>```#/@XG9P,.`!,````7G@```SZ.)F<#
M#@`3````%YX```,^#B9G`PX`$P```!>>```#/HXE9P,.`!,````7G@```SX.
M)6<##@`3````%YX```,^CB1G`PX`$P```!>>```#/@XD9P,.`!,````7G@``
M`SZ.(V<##@`3````%YX```,^#B-G`PX`$P```!>>```#/HXB9P,.`!,````7
MG@```SX.(F<##@`3````%YX```,^CB%G`PX`$P```!>>```#/@XA9P,.`!,`
M```7G@```SZ.(&<##@`3````%YX```,^#B!G`PX`$P```!>>```#/HX?9P,.
M`!,````7G@```SX.'V<##@`3````%YX```,^CAYG`PX`$P```!>>```#/@X>
M9P,.`!,````7G@```SZ.'6<##@`3````%YX```,^#AUG`PX`$P```!>>```#
M/HX<9P,.`!,````7G@```SX.'&<##@`3````%YX```,^CAMG`PX`$P```!>>
M```#/@X;9P,.`!,````=<8;LIN2JAZ+HRN!._)>4``"#M"0:+N@RY`P(,`!H
M"#[.G&`^](%'[_"?^!>6```#-L88LH47E0```S4E&^\@\'"7EP``@[?G&X/'
M!P#ISY>7``"#MX<8%Y0``!,$!"&2EYAC<DF#1Z=+&P5)``X%D^<W`",-]TKO
M\)_NPF47E@```S:F'?)'`[@%`*J&%S<``!,'IR@7-0``$P6E)YCN%.0CL`8!
MB.:0Z@5'#2EC5O<,H04;A3<`$4>089,7-P"VEP4GD..A!>,9I_X.!PAL-I<C
M,`<`2H8!1Y<%``"3A:5?[_#_O3W%"&R3"4$"[_`_W2J)SH47-0``$P4E]>\`
M`!0IS0AL[_"_M^_P?\XB=YQ@N8\!1[WGYF!&9*9DXGE*A09I)6&"@._PG\D7
ME```$P3$$PCL(<7O\)_1EY<``(.WQPF%9C.'1P`88S:7(PL'DCFW"&SO\+^^
M>;<(:`'%[Q"@6D6WSH47-0``$P6%YN\`X`P(Z%G5Y;<11X&_!47O\!^[[_#?
MY>\`(`*JAQ>5```#-:4'@F4P`!-Q`?^!1@%'"HCO\-_A`I"7H0``DX%AAH*`
M```7E0``$P6E"I>7``"3AR<*8XBG`)>7``"#M^?_D<."AX*`%Y4``!,%A0B7
ME0``DX4%"(F-D]<U0/V1OI6%A9G%EY<``(.WI_V1PX*'@H"7EP``@\?'!9WG
M01$&Y)>7``"#MV?^D<<7E0```S5%_X*7[_`?^:)@A4<7EP``(PGW`D$!@H""
M@'&_.7$&_"+X6N"7EP``@[>G]P.[!P!C`0L(2O!.[%+H@T<%`*J)+HHJB1,'
MT`.]PV.&YP"#1QD`!0G]^SL).4$#-`L`(<PF]%;DVH23"M`#2H;.A2*%[_#_
MH+,')`$)Y8/'!P!C@%<#@&2A!'7PHG0">>)I0FJB:N)P(H5"=`)K(6&"@+.$
M9$&-A`4)(R":`$J4\;\!26VW`43YOP)YXFE":MF_<7$B\2;M!O67E```@[2$
M["P`G&`^Y8%'*H3O\'_!#>'B1[UF$6?UCV.%YP`I9V.:YP`BA8E%[_"_H!,U
M%0`1H`%%*F><8+F/`4>1YZIP"G3J9$UA@H#O\+_*,7%*\0;]%YD```,Y">>#
M-PD`/N6!1QG%(OF#1P4`*H2)[TIT*F>#-PD`N8\!1V.=!PSJ<`IY*6&"@";U
M[_"_Q:J$8PD%#$[M)H7O\-^70<V#1C4!DPDU`9N&)OT;A@8`F>(#QAD`;=(#
M1S4!&P<G_9L&!P`!ZX/'&0";AR?]FX8'`*7/\=(BA5+I[_#?D2J*3H7O\%^1
M.P6J``DE[_"_D<Z'(H>7-@``DX8FN'U6A46JB>_P7[HL`$Z%[_#?G?U78PCU
M`.)'O6819_6/8XKG`DZ%[_!?F$Z%[_#_IB:%2FKO\'^.-?4FA>_P_YLBA>_P
MGY5*=*ITZFDUMX/&*0!9MTZ%[_#_[\&_(ODF]4[M4NGO\'^Y2G2J=#&W'7&B
MZ*;DRN"&[$[\4OA6]%KP%YD```,YJ=0#QP4`@S<)`#[D@4>3!]`#+H2JA&,4
M]P`3A!4`(H7O\%^%*HI,`":%[_"?VJJ):<GO\#^$8W5%"Y)*%YL```,[B]&.
M"@/'!`"FAY,&T`-C"@<28P;7``/'%P"%!WW[A9^#.0L`$P4J`#Z5UIGO\'^!
M(["I`"G%@S<+``/'!``3A10`UI>48Q,&T`,C@.8``>NUH`-'!0`%!:.`YP`E
MP[:'A0;C&,?^$P?0`R.`YP"%!P-'!``%!(4'HX_G_G7[(F>#-PD`N8\!1_'C
MYF!&9*9D!FGB>4)ZHGH">R5A@H"#1P0`!02%":./^?[QVX-'!``%!(4)HX_Y
M_OWST;>VAV6W7NQBZ!>;```#.^O$`SP+`(,W#`"MR^*'@4F89Z$'SH:%*67_
MC2:3E38`EY<``(.G!\T7EP``$P>'S)7KA4<NA1S#[_`/]*J+,<63FCD`XH56
MAN_P'XTC,'L!FX<9`(X'OILCL`L`XFM";$["X;UBA>_P/Y4C,*L`JHL)S9.:
M.0#IOX%'\;W!18%)1;=>[&+H[_`_GN)K0FP=MUUQHN#]<@5D)OQ*^$[T4O"&
MY%;L$P>$`!:1"I>7F0``@[G)N"J)+HH3!O3_+``7-0``$P4EDX.W"0`<XX%'
M[_"O]IL$!0!C7I``DP<$`8J7,X2'0)N']/\^E`-'A/\IXYWOEY<``(.WY[92
MALJ%DI>(8^_P;^Z%9Z$'BI>88X.W"0"YCP%'J>.%8A:1IF`&9.)T0GFB>0)Z
MXFIA88*`OH0@`"*%)H:3!?`"[_#_@E79EY<``(.W![*FAB*&DI>(8\J%[_!O
M^D6_[_`?D4$1(N`7E````S0$L`;DEW8``).&YIRS!T0`B&,7E@```S8&KY<U
M``"3A06([_`?BA*4"&`"9*)@%S<``!,'Q[^ZAH%'%Q8``!,&1N27-0``DX6%
MAT$!;_!O\9>7``"#MZ>JEW8``).&II<7E@```S8FJI*7B&.7-0``DX7E@F_P
M_X1=<?ERB6>&Y*+@)OQ*^$[T$X>'`1:1"I>7F0``@[DII(.W"0`<XX%'[_`O
MZ2``!68JAP4&(H67-P``DX='@I<V``"3AD:"A47O\"__A6?!![,$\0`BA::%
M!6;O\`_@&P0%``%)8T\$`!L%%`#O\._2*HD!R2*&IH5*E._P#^,C``0`B6?A
M!XJ7F&.#MPD`N8\!1YGKB6(6D:9@2H4&9.)T0GFB>6%A@H#O\"_^D;\5<?UR
MA6>BZ:;ERN%:\8;M3OU2^5;U7NUBZ1.'AP@6D0J7%YL```,[JY@JB2Z$%R4`
M`!,%Y7E,`(,W"P`<XX%'[_"_GZJ$DP7P`DJ%[_`/Y3'!%R4``!,%I7C*A>_P
M7[]*A85GDX>'"(J7F&.#-PL`N8\!1V.7!Q*%8A:1[F!.9*YD#FGJ>4IZJGH*
M>^IK2FPM88*`(H7O\&_CER4``).%)77O\*^^*H1-U85JDX<*"8J7LXM708-'
M!`"3"8$($PJ!`-G/D<2BA2:%[_`OU27-(H7O\*_`DP?U_Z*7*HR3!O`"8VCT
M`#&H(X`'`/T78P;T``/'!P#C"=?^(H7O\`^^*HQ*A>_PC[UBE04%XW-5]85%
M(H=*B)<G``"3A^=MER8``).&YFT%9DZ%[_`OYM*%3H7O\*_)`>F#IXOXO68A
M9_6/8X#G!)<E``"3A65J`47O\,^S*H3C#@7N@T<$`+WSF<B#QP0`FX<G_1N'
M!P"9XP/'%`!IVP5,%R0``!,$Q&1)MX5%3H7O\&^Y5?W.A1<E```3!>5D[_"_
MJTZ%[_`/T\FU[_"OXT$1DP7P`B+@!N0JA._PK]09P1,$%0`BA0)DHF!!`6_P
MC]!Y<85G_7)*Z`;T(O`F[!.'AP`6D1>)```#.0E]"I>#-PD`'..!1T'!@T<%
M`*J$I<_O\$^N$P85`(5G*H1C[L<(.`"FA3J%[_#OOI,']/^JEY,&\`)C:/4`
M$:@C@`<`_1=CAJ<``\<'`.,)U_X@`"*%DP7P`N_P#\P=Q6-LI`0H`._P3\B%
M9Z$'BI>88X,W"0"YCP%'H>>%8A:1HG`"=.)D0FE%88*`A6>A!XJ7F&.#-PD`
MN8\!1YWCA6(6D:)P`G3B9$)I%R4``!,%A5-%86_P;\,C``4`9;<!16VW[_"/
MTWEQ(O`F[$KH!O27A```@[2D;YQ@/N2!1T``%XD```,YJ6^BA1<E```3!853
M[_!O]@W%$D>#-PD`#@>ZEYAGF.-MTYAKH0>8XVW_HH47)0``$P4%4>_P[_-I
M_1>)```#.:EKHH47)0``$P6%4._P;_(-Q1)'@S<)``X'NI>89YCC;=.8:Z$'
MF.-M_Z*%%R4``!,%!4[O\._O:?T7B0```SFI9Z*%%R4``!,%!4WO\&_N#<42
M1X,W"0`.![J7F&>8XVW3F&NA!YCC;?^BA1<E```3!85*[_#OZVG]%XD```,Y
MJ6.BA1<E```3!05*[_!OZ@W%$D>#-PD`#@>ZEYAGF.-MTYAKH0>8XVW_HH47
M)0``$P6%1^_P[^=I_1>)```#.:E?HH47)0``$P6%1N_P;^8-Q1)'@S<)``X'
MNI>89YCC;=.8:Z$'F.-M_Z*%%R4``!,%!43O\._C:?T7B0```SFI6Z*%%R4`
M`!,%A4/O\&_B#<421X,W"0`.![J7F&>8XVW3F&NA!YCC;?^BA1<E```3!05!
M[_#OWVG]%XD```,YJ5>BA1<E```3!04X[_!OW@W%$D>#-PD`#@>ZEYAGF.-M
MTYAKH0>8XVW_HH47)0``$P6%->_P[]MI_1>)```#.:E3HH47)0``$P6%/._P
M;]H-Q1)'@S<)``X'NI>89YCC;=.8:Z$'F.-M_Z*%%R4``!,%!3KO\._7:?T7
MB0```SFI3Z*%%R4``!,%A3GO\&_6#<421X,W"0`.![J7F&>8XVW3F&NA!YCC
M;?^BA1<E```3!04W[_#OTVG]%XD```,YJ4NBA1<E```3!84V[_!OT@W%$D>#
M-PD`#@>ZEYAGF.-MTYAKH0>8XVW_HH47)0``$P4%-._P[\]I_1>)```#.:E'
MHH47)0``$P4%*>_P;\X-Q1)'@S<)``X'NI>89YCC;=.8:Z$'F.-M_Z*%%R4`
M`!,%A2;O\._+:?VBA1<E```3!04P[_#ORJJ%&<47)0``$P4%+>_P3^NBA1<E
M```3!:4O[_`/R:J%&<47)0``$P4E,._P;^FBA1<E```3!44P[_`OQZJ%'<D7
M)0``$P7%'^_PC^<B9YQ@N8\!1Z'C`G2B<.)D0FF7)0``DX7E+Q<E```3!>4C
M16%O\`_EHH47)0``$P7E+._PS\*JA6'5%R4``!,%Y2/O\"_C;;_O\(^;`1$B
MZ`;L%X0```,TY#=,`!<E```3!<4A'&`^Y(%'[_!/OQ7!@T<%``%%B<>3AP?]
M,S7P`")G'&"YCP%'F>?B8$)D!6&"@`%%];?O\*^6'7$&[!>#```#,R,W*HX#
M-0,`$P.!`B[T,O@V_'*&NN`7C@```SYN,;[DPNC&[)J&A46#-PX`/N2!1QK@
M[^"_ZQ,%\`_OX#_G77'!<L%G2OA.]%+PAN2BX";\5NQ:Z!.'AP`6D0J7%XH`
M``,Z"BV#-PH`'..!1PE&@46JB>_@O_83"?7_$U?Y0T&3LP?I`,(7P9.9CS,)
M^4!C10D(BH3]6AU+`4;*A4Z%[^#_\V,#50E!9B$&IH5.A>_P[X`!)6,$50=C
M?*L$814SA*0`8W:4`*F@?11C8Y0$(4:7A0``DX5%+"*%[^`_[6WU,P4D0$J5
MP6>A!XJ7F&.#-PH`N8\!1YWOP6(6D:9@!F3B=$)YHGD">N)J0FMA88*`P7<^
MF>,2^?A]5?&W%R4``!,%A1;O\#_M%R4``!,%Q13O\'_L[_"/@D$1!N3OX!_1
M[^#?^Q'!"&&B8$$!@H`Y<2;T2O`&_!>)```#.6D=JH1,`!<E```3!243@S<)
M`#[D@4?O\(^D&<4B^(-'!0`JA)WC0G0B9X,W"0"YCP%'IH47)0``$P5%$*WG
MXG"B=`)Y(6%O\._")H5.[._@/\NJB2*%[^"_RDZ5"07OX#_+(H@FAY<G``"3
MAZ?ZER8``).&)OM]5H5%*H3OX%_S(F>#-PD`N8\!1Y7CHH5"=.)IXG"B=`)Y
M%R4``!,%!0HA86_P+[TB^$[L[^!_]>_@/_67AP``DX=G&`.XAP-E<0._!P&#
MOH<!`[X'`@.SAP*#N`<#ROK.]M+R!N<BXQ,)P0$7B@```SKJ#JJ)%R8``!,&
M1@:7)@``DX9&[Q<G```3!\<%ER<``).'QP7"_,J%%R4``!,%!>X#.`H`0OX!
M2`+X@N3ZZ/;L\O":],;X,O`V]#K\ON#O\(^2$<6#1P4`*H1CG@<<IO[6[N_@
M?[KOX#_E8PL%%`!A8P@$%"*%[^`_N@8%!07OX+^Z`T<$`*J$JHH9SR:%ER8`
M`).&IO]]5H5%[^#_X@-'%``%!(D$??.$"!<E```3!67T(:"(9*$$#<'*A>_P
MKXLJA&W9@T<%`/77[_#OE'W1(H7OX'_3*H09[000@&`!S(-'!`!CC`<,(H7O
M\.^27>V`9*$$=?0BA>_@'[*JA%:%[^"?L:F<FX1$0":%[^#?L=:(ER<``).'
MY^$BAQ<H```3"$CWER8``).&1O=]5H5%JHKOX'_95H63!0`<[^#?ROU78QCU
M`._@/[`<045'8Y3G#`P!5H7OX#_/*H09Y<I'O6819_6/8X#G"I>'``"#M^?[
M@[8)`(AC5H<7)@``$P;F]H5%[^!?TH%$<G>#-PH`N8\!1V.6!RZZ8!ID]FI6
M>;9Y%GHFA?9T66&"@"*%[^"_Q2J$H03C`P7R-;\!1"6_)!B(8!G)RH7OX/_Z
M`<6#1P4`A>.(9*$$??4U1>_@WZ2JA*J*%R0``!,$Q.<3!S`%<;WOX'_!*H2A
M!&'5[^#?H08%!06MO=KJ:DOOX/^?8P:K!%9KF;\7AP```S<G\8.V"0`(8Q<F
M```3!D;H5H>%1>_@G\>1O^_P7\UR=X,W"@"YCP%'8Y(')"*%&F2Z8%9YMGD6
M>EEA;^`_N\I'WN83!P`<D_?W'V.%YP!6:[9K];TFA>_@?YO*A:J$%R4``!,%
M9>SOX%_OJH5C#`40`[4)`._PS\JJBV,%!1!>A>_@WY<;"P4`C4=CV&<#$P7+
M_UZ5ER4``).%A>GOX!^J">V11V,$^QB;![O_WI<#QP<`DP?P`F,+]Q;*A1<E
M```3!87+[^!_Z6G!@T<%`-7/$P<``V.+YPJ7)0``DX5%TQ<E```3!47)[_"/
MB._@'Z0JB%:')H67*```DXCH\I<G``"3AV?!ER8``).&9N5]5H5%[^"_N7U9
MQ4D7*P``$PNK\!6H[^"?D!Q!8YTW`^_@_Y\%)"J(6N"BB%:'2H8FA9<G``"3
MAT>]ER8``).&1N*%1>_@O[63!0`<)H7OX!^GXP(E_5:%[^!_HZ:%%R4``!,%
M!;COX-__)H7O\%^W5FNV:_6S@[L)`-V]7H6!1>_@_[<JB3'1[_"?I*J)XTX%
M\I,%9?\!1DJ%[^!?G1,+`1#:A4J%&4;OX'^JF4=C'O4(`R<!$+='04.3AP<P
MXQ;W\`-72P"19Y.'AU3C'_?NDX7I_`%&2H7OX'^9(`)*A:*%$P:``N_@GZ:3
M!X`"8Q[U!"*(ER@``).(*.*7)P``DX>GL%:'ER8``).&AM-]5H5%)H4C"`$2
M[^!_J"V_@[F)`..%">A.A>_@;_R-1^/_I^9Q%4Z5ER4``).%!<_OX!^/XQ4%
MYLZ+E;47)0``$P5%SN_P?Y/:ZM[F[^!?J:;^UN[:ZM[F[^"?J#EQ(O@7A```
M`S2$QTKP3NP&_";T4NBS!T0`A&.3"4$`%XD```,Y2<.#QP0+SH47)0``$P7E
MJ@,W"0`ZY`%'HXCT"N_@'\H9Q0-'!0"3!Q`#8POW$N_PS\^S!T0`A&,FA8U&
M!4:7)0``DX6%RN_@C_BJA!W!'&DS!T0`"&.,8Q<F```3!F;)[^#O]YQHC&/<
M11.7EP)C10<0LP=$`(ACC48%1I<E``"3A:7'[^"O]*J$%XH``!,*RL4-P<Z%
M%R4``!,%A9SOX/_!G&@JAHQC:<&S!T0`B&/OX._RLP=$`(1C!4:7)0``DX4E
MQ":%[^"/YJJ%%R8``!,&IL0FA>_@C_`2E!Q@SH47)0``$P7EEJ.(!PKOX!^]
M(SBJ`"J$.<63!0`<(H7OX!^#&P<5`(5'8_#G`L5'8PWU`(,WB@"JAB*&C&,7
M)0``$P6EPN_@OX<B9X,W"0"YCP%'J>OB<$)THG0">>)I0FHA88*``S6*`._P
MGYPC.*H`*H1=\1<E```3!:6\[^`_A(-'%0#CB@?LV;6#-XH`+H6,8^_@7_$]
MO[,'1`"(8^_@#__%O>_@OXUY<2+P)NP&]!>$```#-.2IJH1,`!<E```3!:63
M'&`^Y(%'[^`_L0'-@T<%`(G+$P<``V.&YP"!Q(/'!`"9ZR)G'&"YCP%'H>^B
M<`)TXF1%88*`)H5*Z._PSZ:3!?`"*HGOX&_Y&<$3"14`2H7OX*_U$4:7)0``
MDX7%G>_@S]$9P4)I=;\B9QQ@N8\!1Y'K`G1"::)P)H7B9$5A;^!_N4KH[^!_
M@Q,!`=27@P``@[/CGS0`P6XC/!$J(SB!*B,TD2HC,"$K(SPQ*9,(A0.3#X4'
M@[<#`",T\2B!1S:(DXX.\#</_P`#M@@`H0A!")-5!@(3%X8!$Y.%`9,2A@"3
M5X8"`A<37H8`$U2&`P&3`A.S\N(!L_?7`1-3`P(S9U<`,W[>`:(%P8\S9\<!
M&U:&`;/UY0&SYV<`48_-CR,XZ/XC//C^XY'X^T9_YGX*9V)N`G.B>$)XXG6&
M;Q.$!B`1H+*/L&*<8KJ"H0:QC[/'YP&SQ\<!$Y<7`/V#78\"%P&3N/X:CG:/
M1H.6CL*(+HC^A>,8U/P080QI`SB%`2)N@SB%``,S!0*35[8!$Q=6`#>/@EH3
M#Y^978]ZGK/&!0$"%QJ>D]XH``&3DY?H`;/V%@&SY]<!<I>SQ@8!-I<3G@<"
MPF837@X"DQ\'`C/'Q0&3WP\"<8_ZEI/2OP&3GE\`+8_"EK/N7@`35"8`XF(V
MEY,6Y@'!CG:7DQX'`K6/D]X.`C.'X@&S]_<!$]2^`2Z7DY)>`+/'QP&SXH(`
MNI<"=!.7[P&3WR\`,V?W`9:7@A>3D@8"N8Z!D[,/Y`&3T@("L_;6`7Z>$]2W
M`9.?5P"SQE8`\I8S[H\`\I:B?Q.>[@&3WBX`,V[>`1,4!P*"%C-'QP&!D@&0
MLX[O`7V/EIZ3GU8`D]*V`2&/=I>S[E\`=I?"?Y.>YP&)@[/N_@"S1]X!DQ(.
M`@(7`9.3T@(",X[O`?6/(IZ3'U<`$U2W`;/'5P#RES/NCP#RE^)_$Y[F`8F"
M,V[>`+/&S@$3E`X"@A>!DP&0LX[O`?F.EIZ3GU<`D]*W`:&.]I:S[E\`]I:&
M;Y,>YP$)@[/N[@`S1]X!DQ(.`H(6@9*3T@(",X[O`7V/(IZ3GU8`$]2V`3-'
M5P!RES/NCP!REZ9O$Y[G`8F#,V[^`+/'S@$3E`X"`A<!DP&0LX[O`?6/EIZ3
M'U<`DU*W`:&/]I>S[E\`]I?&;Y.>Y@&)@K/NW@"S1MX!DQ(.`H(7@9.3T@("
M,X[O`?F.(IZ3GU<`$]2W`;/&5@#REC/NCP#REN9O$Q[G`0F#,V[N`#/'S@$3
ME`X"@A:!D@&0LX[O`7V/EIZ3GU8`D]*V`2&/=I>S[E\`=I>&?Y.>YP&)@[/N
M_@"S1]X!DQ(.`@(7`9.3T@(",X[O`?6/(IZ3'U<`$U2W`;/'5P#RES/NCP#R
MEZ9_$Y[F`8F",V[>`+/&S@$3E`X"@A>!DP&0LX[O`?F.EIZ3GU<`D]*W`:&.
M]I:S[E\`]I;&?Y,>YP$)@[/N[@`S1]X!DQ(.`H(6@9*3T@(",X[O`7V/(IZ3
MGU8`$]2V`3-'5P!RES/NCP!RE^9_$Y[G`8F#,V[^`+/'S@$3E`X"`A<!DP&0
MLX[O`?6/EIZ3'U<`DU*W`:&/]I>S[E\`]I>*;Y.>Y@&)@K/NW@"S1MX!DQ(.
M`H(7@9.3T@(",X[O`?F.(IZ3GU<`$]2W`;/&5@#REC/NCP#REJIO$Q[G`0F#
M,V[N`#/'S@$3E`X"@A:!D@&0LX[O`7V/EIZ3GU8`D]*V`2&/=I>S[E\`=I>3
MG^<!RFZ)@[/O_P"S1_X!DQ(.`@(7`9.3T@(",X[N`?6/(IZ3'E<`$U2W`;/'
M5P#RES/NC@#RE^ID$]XF`).>Y@&"%X&3L^[.`1/9MP&SQM\!$Y0/`A.>5P`!
MD+./Y`$S;BX!^8Z6GZ&.`AX37@X"_I;RE@IY$UXG`).2!@*3'^<!D]("`K/O
MSP$SQ_X!DY0.`A.>4@"S#ND!$]^R`8&0,V[N`7V/HIXECP(>$UX.`G:7$Y3G
M`8F#<I==C+/'CP"J?A,9!P(360D"M8^W]MENDX86NA-?N0$3'ED`,V[N`;:>
M@A>FGH&3`A[VEQ->#@(^GA.?X@&3TB(`,V]?`,IWDQ0.`H&0LT[D`9/2M`&S
MSNX`@A\3EU0`D]\/`C-G5P"VEX(>D]X.`OZ7`A?VEP&3/I>3'ND!$UDI`+/N
M+@'J=Y,2!P*3T@("LT_?`1/9L@&SS\\!`A03GE(``9`S;BX!MI>"'Y/?#P*B
MEP(>_I<37@X"/IZ3G^0!B8"S[Y\`CF<3%`X"`9"SQ/X!$UFT`;F,`A\3%U0`
M$U\/`C-G)P&VEX(4@9#ZEP(7II<!DSZ7$Y_B`9/7(@`S;_\`DQ('`JYGD]("
M`K/$[P$3V;(!L\3$`8(>$YY2`)/>#@(S;BX!MI>"%(&0]I<"'J:7$UX.`CZ>
MDQ[D`9-7)`"S[OX`$Q0.`LYG`9"S1-\!$UFT`;F,@A\3%U0`D]\/`C-G)P&V
MEX(4@9#^EP(7II<!DSZ7DY_B`9/7(@"S[_\`DQ('`NYGD]("`K/$_@$3V;(!
ML\3$`0(?$YY2`!-?#P(S;BX!MI>"%(&0^I<"'J:7$UX.`CZ>$Q_D`9-7)``S
M;_\`$Q0.`HYW`9"SQ.\!$UFT`;F,@AX3%U0`D]X.`C-G)P&VEX(4@9#VEP(7
MII<!DSZ7DY[B`9/7(@"S[OX`DQ('`JYWD]("`K-$WP$3V;(!L\3$`8(?$YY2
M`)/?#P(S;BX!MI>"%(&0_I<"'J:7$UX.`CZ>DQ_D`9-7)`"S[_\`$Q0.`LYW
M`9"SQ/X!$UFT`;F,`A\3%U0`$U\/`C-G)P&VEX(4@9#ZEP(7II<!DSZ7$Y_B
M`9/7(@`S;_\`DQ('`NYWD]("`K/$[P$3V;(!L\3$`8(>$YY2`)/>#@(S;BX!
MMI>"%(&0]I<"'J:7$UX.`CZ>DQ[D`9-7)`"S[OX`$Q0.`I)G`9"S1-\!$UFT
M`;F,@A\3%U0`D]\/`C-G)P&VEX(4@9#^EP(7II<!DSZ7DY_B`9/7(@"S[_\`
MDQ('`K)GD]("`K/$_@$3V;(!L\3$`0(?$YY2`!-?#P(S;BX!MI>"%(&0^I<"
M'J:7$UX.`CZ>$Q_D`9-7)``S;_\`$Q0.`M)G`9"SQ.\!$UFT`;F,@AX3%U0`
MD]X.`C-G)P&VEX(4@9#VEP(7II<!DSZ7DY[B`9/2(@"S[EX`\F>3%`<"@9"S
M0M\!$]FT`;/"P@&"'Q.>5`"3WP\",VXN`;:7@A*3T@("_I<"'I:7$UX.`CZ>
MDQ+D`9-7)`"SXO(`$Q0.`I)W`9"SSUX`$UFT`;//[P`"'Q,75``37P\",V<G
M`;:7@A^3WP\"^I<"%_Z7`9,^EY.?Y`&)@+/OGP"R=Q,9!P(360D",\_R`9-4
MN0$S3\\!@AX3'ED`D]X.`C-NG@"VEP(?$U\/`O:7`A[ZEQ->#@*SCL<!$Q_D
M`0F`,V^/`-)WDY0.`H&0,\[O`1/4M`$S3NX`@A(3EU0`D]("`D&/MI<"'A->
M#@*6EP(7`9,3%.D!\I<362D`,V0D`3..YP!R=[-'CP"SQ]<!@A^3'@X"D]X.
M`I/?#P(VEX(7$]F^`8&3?I>3GUX`/I>3DN0!L^<O`8F`L^*2`#Z7EF>S3U0`
MDQ0/`C/.SP$3'P<"$U\/`H&0MI<"'I-?OP$37@X"II>3%E\`L^;V`1.7[@'R
MEY/>+@`S9]<!MI>V;K?VQB.3'P<"$YX'`I.7)@"3A\?-D]\/`K/FX@`"%!->
M#@*S]/(!`9"^GK/VY@&BGL6.$Q1>`)-4O@'VEK-NE`#VEE9DDQ3O`9->+P"S
M[M0!$Y\"`C-GUP&3D@8"D]("`K,&]``S=\<!,_3^`1-?#P(VGY/4L@%!CQ.4
M4@"3%NX!>I<37BX`,V^4`+/FQ@%ZEW9O$Y0&`@&0,^[>``(7`9.S](X`/I\S
M?EX`?I\S;IX`DQ]7`)-4MP%ZGC/OGP!ZGI9T$YGB`1/?(@`S;^D!DQ\.`K/F
MY@&"'I/?#P*S<H\`,X[T`)/>#@+YCG:>L^96`!/9OP&3DE\`DQ3G`9->)P`S
MA\8!L^;4`3/N(@&V?G*7DY(&`I/2`@(S;M\``A<!D[-T7P"^GC-^_@&BGC-N
MG@`3%%<`DU2W`7:>LVZ4`%9TDY3O`9/?+P"S[_0!=IZ3'@X"L^;V`0(?D]X.
M`C,.]``37P\",_1?`/F.>I[!CA/9O@$3E%X`DQ3G`1-?)P`SA\8!L^;D`3-N
M)`%V?W*7$Y0&`@&0,^[?``(7`9.S](\`/I\S?MX!%I\S;IX`DQ)7`)-4MP%Z
MGC/OD@":8I.4[@&3WBX`L^[4`7J>$Q\.`K/FU@&"'Q-?#P(SCO(`D]\/`K/R
MC@#YCGZ>L^96`!-9OP&3$E\`DQ3G`9-?)P`SA\8!L^;T`3/N(@&Z;W*7DY(&
M`I/2`@(S[MX``A<!D[/T7@"^GS-^[@&BGS-NG@`3%%<`DU2W`7Z>LV^4`%ID
MDQ3O`1-?+P`S[^0!?IZ3'PX"L^;F`8(>D]\/`C,.]`"3W@X",W1?`/F.=I[!
MCA/9OP$3E%\`DQ3G`9->)P`SA\8!L^;4`3-N)`'Z;G*7$Y0&`@&0,V[?``(7
M`9.S=(\`OIXS?OX!EIXS;IX`DQ)7`)-4MP%VGK/ND@":<I.4[P&3WR\`L^_T
M`7:>DQX.`K/F]@$"'Y/>#@(SCO(`$U\/`K/RCP#YCGJ>L^96`!/9O@&3DEX`
MDQ3G`1-?)P`SA\8!L^;D`3/N(@$Z?W*7DY(&`I/2`@(S[M\``A<!D[/T7P`^
MGS-^W@$BGS-NG@`3%%<`DU2W`7J>,V^4`%ITDY3N`9/>+@"S[M0!>IX3'PX"
ML^;6`8(?$U\/`C,.]`"3WP\",_1>`/F.?I[!CA-9OP$3%%\`DQ3G`9-?)P`S
MA\8!L^;T`3-N)`'Z?W*7$Y0&`@&0,^[>``(7`9.S](X`OI\S?NX!EI\S;IX`
MDQ)7`)-4MP%^GK/OD@">8I,4[P$37R\`,^_D`7Z>DQ\.`K/FY@&"'I/?#P(S
MCO(`D]X.`K-RCP#YCG:>D]2_`9.>7P"SYE8`DQ+G`0F#,^?B`/*6,^Z>`+YN
M\I:3$@<"D]("`C-N[P""%H&2LW1?`+Z>,W[^`:*>,VZ>`!.45@"3U+8!=IZS
M;I0`=IY>9).4[P&3WR\`DQX.`C/N]`$S9\<!`A^3W@X"LP_T`'6/,W1>`!-?
M#P)^GT&/DY]>`!/4O@%ZES/OCP#^9'J7$Y_F`8F"LV;?``(7`9.3GP8"D]\/
M`C-OW@`36;<!OI03%%<`II(S9"0!LW3^`3-_WP$S;Y\``A0!D!:?GG0BGY,2
M#P*3T@("$Y3N`9/>+@`S9-0!OI23GE(`D]>R`<&.L^[^``(>L_?F`!->#@*3
ME@X"LW[T`2:>L^?7`?*7@9*^EI,4YP$)@]F,$YD&`KY^M[>8,A-9"0(S1Y0`
MB@>3AV<=,T?G`1,>60`37[D!,V[N`;Z>`A?^G@&3`AX37@X"=I>S#L<!$Y_B
M`9/2(@`S;U\`DYD.`EY^D]D)`C/'Y`&3W[D!-8\"%).660`!D+/F]@$^G@(7
M(IX!DX(6@9)RES,.UP"3'^D!$UDI`+/O+P&3$@X"?G>3T@("LT;_`1/4L@&S
MSM8!@A23EE(`@9#!CCZ7@AZ3W@X")I>"%G:7@9*ZEI.>Z0&3V2D`L^X^`1.4
M!@(#-P$@`9"SQ-\!$UFT`;/$Q`$"'Q,>5``37P\",VXN`3Z7@A2!D'J7`AXF
MEQ->#@(ZGA.?X@$3UR(`,V_O`),2#@(#-X$@D]("`K/$[@$3V;(!M8R"'Y.6
M4@"3WP\"L^8F`3Z7@A2!D'Z7@A8FEX&2NI:3'^0!$U<D`+/O[P`3E`8"`S<!
M(0&0LT3_`1-9M`&SQ,0!@AX3'E0`D]X.`C-N+@$^EX(4@9!VEP(>)I<37@X"
M.IZ3GN(!$]<B`+/N[@"3$@X"`S>!(9/2`@*SQ-\!$]FR`;6,`A^3EE(`$U\/
M`K/F)@$^EX(4@9!ZEX(6)I>!DKJ6$Q_D`1-7)``S;^\`$Y0&`@,W`2(!D+/$
M[@$36;0!L\3$`8(?$QY4`)/?#P(S;BX!/I>"%(&0?I<"'B:7$UX.`CJ>DY_B
M`1/7(@"S[^\`DQ(.`@,W@2*3T@("LT3_`1/9L@&UC((>DY92`)/>#@*SYB8!
M/I>"%(&0=I>"%B:7@9*ZEI,>Y`$35R0`L^[N`!.4!@(#-P$C`9"SQ-\!$UFT
M`;/$Q`$"'Q,>5``37P\",VXN`3Z7@A2!D'J7`AXFEQ->#@(ZGA.?X@$3UR(`
M,V_O`),2#@(#-X$CD]("`K/$[@$3V;(!M8R"'Y.64@"3WP\"L^8F`3Z7@A2!
MD'Z7@A8FEX&2NI:3'^0!$U<D`+/O[P`3E`8"`S<!)`&0LT3_`1-9M`&SQ,0!
M@AX3'E0`D]X.`C-N+@$^EX(4@9!VEP(>)I<37@X".IZ3GN(!$]<B`+/N[@"3
M$@X"`S>!))/2`@*SQ-\!$]FR`;6,`A^3EE(`$U\/`K/F)@$^EX(4@9!ZEX(6
M)I>!DKJ6$Q_D`1-7)``S;^\`$Y0&`@,W`24!D+/$[@$36;0!L\3$`8(?$QY4
M`)/?#P(S;BX!/I>"%(&0?I<"'B:7$UX.`CJ>DY_B`1/7(@"S[^\`DQ(.`@,W
M@263T@("LT3_`1/9L@&UC((>DY92`)/>#@*SYB8!/I>"%(&0=I>"%B:7@9*Z
MEI,>Y`$35R0`L^[N`!.4!@(#-P$F`9"SQ-\!$UFT`;/$Q`$"'Q,>5``37P\"
M,VXN`3Z7@A2!D'J7`AXFEQ->#@(ZGA.?X@$3UR(`,V_O`),2#@(#-X$FD]("
M`K/$[@$3V;(!M8R"'Y.64@"3WP\"L^8F`3Z7@A2!D'Z7@A8FEX&2NI:3'^0!
M$U<D`+/O[P`3E`8"`S<!)P&0LT3_`1-9M`&SQ,0!@AX3'E0`D]X.`C-N+@$^
MEX(4@9!VEP(>)I>3GN(!$UX.`I/2(@"S[EX`.IX#-X$GL\+?`;/&T@`"'Q-?
M#P*3$@X"/I>"%I/2`@*!DGJ7DY12`!/9L@$VEQ,?Y`&#-@$H"8`S;X\`L^0D
M`3/$[@$FE[:7@A\"%S-.Q`$!D[*7D]\/`@(>DU:W`1,65P`37@X"_I=5CO*7
MDY;B`9/2(@"RE[/F5@`S!A<!=I,SA[8`0I^"%X&3DQ8&`I,5`P(3%@\"`A>!
MDH&1`9(!DQSA%.4,\1#M@S:!*(.W`P"UCX%&&.F1[X,P@2L#-`$K@S2!*@,Y
M`2J#.8$I$P$!+(*`[]!ON4$1$P4`"`;D[]"OB1=(```#..A&MW9=3#=WZ6&&
M!K<E16<W5C(0!@>3AN;/DX45,!,&9D<3!P<?%.DC-`4"(S@%`B,L!08,X2,T
M!0$0[1CQHF!!`8*`77$F_$KX4O!6[(;DHN!.]!AUDQ<V`#*)NI<0>8(7@9,S
MM^<`JH235MD!*%TZEC.'Q@"<])CXKHH3BH0#+>V3!_`#8]HG!9M9:0!:Z!N+
M^?]>Y)H)DQL+`I/;"P+6F5:$HH43!@`$4H7OT$^/$P0$!":%[^"?J>,5-/\[
M"V!!&QMK`)H+&PD)_).*"@0["2L!WII":Z)KUH52A4J&[]`/C".L)`>F8`9D
MXG1">:)Y`GKB:F%A@H"3!P`$B9\^A&-)^0*;"00`$XJ$`TZ&4I76A>_0SXB\
M7!,'``2AG[S<XY/G_":%.PF)0,Z:[^`?HH&_2H3!OSEQ(O@F]$[L4NA:X`;\
M2O!6Y`.YA0*#UH4"`]<%`Y-7.0`3BX4#D_?W`Y/9A@`36H<`FY:&`!L7AP`S
M!OL`+H2SZ=D`DP4`^#-JZ@"#.@0#A2<C`+8`PAE"&A,&@`.JA)/9"0,S!?L`
M$UH*`V-5]A`3!P`$NP?W0!%'8__G$`E'8_/G$&.>!PXBA>_@WYA:A1,&@`.!
M1>_0+Y*35XD!$]>*`1-9"0&3V@H!(QE$!R,;-`>C"%0'(PKT!J,*)`<BA2,(
MY`;OX#^5'&`BA>&#(X#T`!Q@P8.C@/0`'&"A@R.!]``<8*.!]``<9.&#(X+T
M`!QDP8.C@O0`'&2A@R.#]``<9*.#]``<:.&#(X3T`!QHP8.CA/0`'&BA@R.%
M]``<:*.%]``<;.&#(X;T`!QLP8.CAO0`'&RA@R.']``<;*.']``<<.&#(XCT
M`!QPP8.CB/0`''"A@R.)]``<<*.)]`!"=.)PHG0">>)I0FJB:@)K(6%OP'_W
M'9Z!1>_0[X,QOR,`!0`1MR,`!0"C``4`^1<ZE>.+!^[MMR,`!0"C``4`(P$%
M`*,!!0#Q%SJ5"4?CZ^?LT;^79@``@[9&+&_`W^0!``(``````"5S+R5S````
M+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@``
M````26YT97)N86QS.CI005(Z.D)/3U0`````97AE```````O<')O8R\E:2\E
M<P``````+@````````!005)?5$5-4```````````4$%27U!23T=.04U%````
M`#H`````````+P`````````E<R5S)7,``%!%4DPU3$E"``````````!015),
M3$E"`%!%4DPU3U!4``````````!015),24\``%!!4E])3DE424%,25I%1`!0
M05)?4U!!5TY%1```````4$%27T-,14%.`````````%!!4E]$14)51P``````
M``!005)?0T%#2$4`````````4$%27T=,3T)!3%]$14)51P``````````4$%2
M7T=,3T)!3%]435!$25(`````````4$%27U1-4$1)4@```````%!!4E]'3$]"
M04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.```````````Q`````````&QS965K
M(&9A:6QE9`````!R96%D(&9A:6QE9```````3$1?3$E"4D%265]0051(`%-9
M4U1%30``+W1M<`````!54T52`````%5315).04U%```````````E,#)X````
M`'!A<BT`````)7,E<R5S)7,``````````"5S.B!C<F5A=&EO;B!O9B!P<FEV
M871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H````````E
M<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@
M<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````````4$%4
M2`````!P87)L`````"YP87(`````<VAO<G0@<F5A9````````"5S)7-C86-H
M92TE<R5S```E<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E<P``````
M````&`````````!P97)L`````#``````````4$%2.CI086-K97(Z.E9%4E-)
M3TX`````,2XP-C,```!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R
M>0``````````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER
M96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``````````+64````````M
M+0```````%1-4$1)4@``5$5-4$1)4@!414U0`````%1-4```````979A;"`G
M97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@
M;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L
M.PIM>2`H)%!!4E]-04=)0RP@)$9)3$5?;V9F<V5T7W-I>F4L("1C86-H95]N
M86UE7W-I>F4I.PI"14=)3B!["B1005)?34%'24,@/2`B7&Y005(N<&U<;B([
M"B1&24Q%7V]F9G-E=%]S:7IE(#T@-#L@("`C('!A8VLH(DXB*0HD8V%C:&5?
M;F%M95]S:7IE(#T@-#`["B102UI)4%]-04=)0R`](")02UPP,#-<,#`T(CL*
M?0IS=6(@9FEN9%]P87)?;6%G:6,*>PIM>2`H)&9H*2`]($!?.PIM>2`D8VAU
M;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D
M9F@["FUY("1P;W,@/2`H)'-I>F4M,2D@+2`H)'-I>F4M,2D@)2`D8VAU;FM?
M<VEZ93L@("`@("`C($Y/5$4Z("1P;W,@:7,@82!M=6QT:7!L92!O9B`D8VAU
M;FM?<VEZ90IW:&EL92`H)'!O<R`^/2`P*2!["G-E96L@)&9H+"`D<&]S+"`P
M.PIR96%D("1F:"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-
M04=)0RD["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)0RDI
M(#X](#`I('L*<F5T=7)N("1P;W,@*R`D:3L*?0HD<&]S("T]("1C:'5N:U]S
M:7IE.PI]"G)E='5R;B`M,3L*?0IM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L
M($!T;7!F:6QE+"`E36]D=6QE0V%C:&4I.PI%3D0@>R!I9B`H)$5.5GM005)?
M0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"
M87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL
M93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<5M296UO
M=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(ETI.PI&:6QE.CI&:6YD.CIF:6YD
M9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T
M96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>
M3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I4
M14U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z
M.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]
M/B`P+`HI.PIM>2`D9FEL96YA;64@/2`D=&UP+3YF:6QE;F%M93L*<')I;G0@
M)'1M<"`\/"(N+BXB.PIX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR
M;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T
M:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M
M("<D9FEL96YA;64G"BXN+@IC;&]S92`D=&UP.PIC:&UO9"`P-S`P+"`D9FEL
M96YA;64["FUY("1C;60@/2`B)&9I;&5N86UE(#XO9&5V+VYU;&P@,CXF,2`F
M(CL*<WES=&5M*"1C;60I.PIO=71S*'%Q6U-P87=N960@8F%C:V=R;W5N9"!P
M<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@)&9I;&5N86UE72D["GT*?2!]
M"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9)
M;G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*
M;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)7-Y<R`]("@*<&%T
M:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E
M>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@
M/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I
M;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*;W5T
M<RAQ<5M<)'!R;V=N86UE(#T@(B1P<F]G;F%M92)=*3L*7W-E=%]P87)?=&5M
M<"@I.PIO=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0
M?2)=*3L*;7D@*"1S=&%R=%]P;W,L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI
M.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*=6YL
M97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE*2!["F]U=',H<7%;
M0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=*3L@(",@9&]N)W0@
M=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER97,@17)R;F\N<&T*;&%S="!-04=)
M0SL*?0IM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H*E]&2"D["FEF
M("@D;6%G:6-?<&]S(#P@,"D@>PIO=71S*'%Q6T-A;B=T(&9I;F0@;6%G:6,@
M<W1R:6YG("(D4$%27TU!1TE#(B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA
M<W0@34%'24,["GT*;W5T<R@B1F]U;F0@4$%2(&UA9VEC(&%T('!O<VET:6]N
M("1M86=I8U]P;W,B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O
M9F9S971?<VEZ92`M(&QE;F=T:"@B7#!#04-(12(I+"`P.PIR96%D(%]&2"P@
M)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&YE(")<,$-!0TA%
M(B`F)B`D8G5F(&YE(")<,$-,14%.(BD@>PIO=71S*").;R!C86-H92!M87)K
M97(@9F]U;F0B*3L*;&%S="!-04=)0SL*?0IO=71S*'%Q6T-A8VAE(&UA<FME
M<B`B)&)U9B(@9F]U;F1=*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,
M15]O9F9S971?<VEZ92P@,#L*<F5A9"!?1D@L("1B=68L("1&24Q%7V]F9G-E
M=%]S:7IE.PIM>2`D;V9F<V5T(#T@=6YP86-K*").(BP@)&)U9BD["F]U=',H
M(D]F9G-E="!F<F]M('-T87)T(&]F($9)3$5S(&ES("1O9F9S970B*3L*<V5E
M:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M("1O9F9S
M970L(#`["B1S=&%R=%]O9E]&24Q%7W-E8W1I;VX@/2!T96QL(%]&2#L*;7D@
M)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@
M*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&
M2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B
M=68["F]U=',H<7%;56YP86-K:6YG($9)3$4@(B1F=6QL;F%M92(N+BY=*3L*
M;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I
M(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]
M?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*
M<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE
M9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*
M;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@)&)U9BP@,#<U
M-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE
M;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U
M;&QN86UE.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*
M8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*
M?3L*)')E<75I<F5?;&ES='LD9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L("1B
M=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U
M;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*
M;7D@)&EN9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L97T["G)E='5R;B!U;FQE
M<W,@)&EN9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD24Y#
M>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6
M>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY
M("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R
M96%T92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I
M;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@)&9H
M.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC
M<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F:6QE
M;F%M93L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O<B!D:64@
M<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@)&9H.PI]
M"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE
M("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I
M<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%
M>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H
M*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS
M;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F
M:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL
M96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE
M;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C
M=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL
M96YA;65].PI]"FEF("@D8G5F(&YE("102UI)4%]-04=)0RD@>PIO=71S*'%Q
M6TYO('II<"!F;W5N9"!A9G1E<B!&24Q%('-E8W1I;VX@:6X@9FEL92`B)'!R
M;V=N86UE(ETI.PIL87-T($U!1TE#(#L*?0HD<W1A<G1?<&]S(#T@*'1E;&P@
M7T9(*2`M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@
M0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?
M;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE
M("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0II9B`H(21S=&%R
M=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF
M="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@
M:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@
M("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM
M<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@
M<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R
M"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@
M+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q
M("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@
M)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU
M;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD
M;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I
M=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]
M"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@
M97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N
M)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4
M)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY
M("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-
M4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$
M:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M
M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A
M9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE
M.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*
M?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE
M9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q
M<5M#86XG="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L
M("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II
M<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R
M8VAI=F4@(B1P87(B73L*?0IM>2`E;65T85]P87(@/2!D;R!["FEF("@D>FEP
M(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2![
M"B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M
M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FEF("AD
M969I;F5D("1P87(I('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@
M9&EE('%Q6T-A;B=T(')E860@<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY("1B
M=68["G)E860@)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P87(B(&ES(&YO="!A
M('!A<B!F:6QE72!U;FQE<W,@)&)U9B!E<2`D4$M:25!?34%'24,["F-L;W-E
M("1P:#L*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M
M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/
M7U)$5U(H*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE
M('%Q6T-A;B=T(&-R96%T92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO
M9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(["FEF("AD969I;F5D
M("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI('L*<F5A9"!?1D@L("1L;V%D97(L
M("1S=&%R=%]O9E]&24Q%7W-E8W1I;VX["GT@96QS92!["FQO8V%L("0O(#T@
M=6YD968["B1L;V%D97(@/2`\7T9(/CL*?0II9B`H(21%3E9[4$%27U9%4D)!
M5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER
M92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I
M<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0HD9F@M/G!R:6YT*"1L;V%D97(I
M"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&QO861E<B!T;R`B)&]U="(Z("0A
M73L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?
M;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@
M>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF
M:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV
M;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I
M;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ
M9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]
M("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?
M97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H
M<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E
M9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI
M('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R
M96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%
M+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T
M.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF
M("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE
M*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH
M)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*
M?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N
M>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O
M7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)
M3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL
M92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@
M/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD968["F]P
M96X@;7D@)'1H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A
M9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1T:#X["F-L;W-E("1T:#L*
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB
M961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA
M;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#
M;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*
M?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@
M*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T
M94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C
M;VYT96YT*2DL"B1C;VYT96YT*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!E
M;6)E9&1E9"!&24Q%('1O("(D;W5T(CH@)"%=.PIO=71S*'%Q6U=R:71T96X@
M87,@(B1N86UE(ETI.PI]"GT*:68@*"1Z:7`I('L*)'II<"T^=W)I=&54;T9I
M;&5(86YD;&4H)&9H*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+"F]R(&1I92!Q
M<5M%<G)O<B!W<FET:6YG('II<"!P87)T(&]F("(D;W5T(ET["GT*:68@*"1M
M971A7W!A<GMC;&5A;GTI('L*)&9H+3YP<FEN="@B7#!#3$5!3B(I.PI]"F5L
M<V4@>PII9B`H(61E9FEN960@)&-A8VAE7VYA;64I('L*;7D@)&-T>"`]($1I
M9V5S=#HZ4TA!+3YN97<H,2D["G-E96L@)&9H+"`P+"`P.PHD8W1X+3YA9&1F
M:6QE*"1F:"D["G-E96L@)&9H+"`P+"`R.PHD8V%C:&5?;F%M92`]("1C='@M
M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M
M92P@,"P@)&-A8VAE7VYA;65?<VEZ93L*)&-A8VAE7VYA;64@+CT@(EPP(B!X
M("@D8V%C:&5?;F%M95]S:7IE("T@;&5N9W1H("1C86-H95]N86UE*3L*)&9H
M+3YP<FEN="@D8V%C:&5?;F%M92P*(EPP0T%#2$4B*3L*?0IM>2`D;V9F<V5T
M(#T@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I.PHD9F@M/G!R:6YT*'!A
M8VLH)TXG+"`D;V9F<V5T*2P*)%!!4E]-04=)0RD["B1F:"T^8VQO<V4@;W(@
M9&EE('%Q6T5R<F]R('=R:71I;F<@=')A:6QE<B!O9B`B)&]U="(Z("0A73L*
M8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN
M960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL
M93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z
M.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C
M:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P
M96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE
M9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM
M>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@D>FEP+3YR96%D1G)O;49I
M;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P
M<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P
M,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H
M97LD<')O9VYA;65](#T@)'II<#L*;W5T<R@B17AT<F%C=&EN9R!Z:7`N+BXB
M*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@
M<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M
M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY
M("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S
M<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#
M;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?
M;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL
M92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S
M=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I
M*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@
M86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B72D["GT@96QS92!["F]U
M=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M
M92(N+BY=*3L**"1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N
M86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O
M<B!E>'1R86-T:6YG('II<"!M96UB97(@=&\@(B1D97-T7VYA;64B73L*8VAM
M;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*
M?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\
M("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@
M+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L
M(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!
M4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*
M?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&
M:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@
M1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR
M97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@
M=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*
M<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y
M;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E
M<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR
M97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X
M<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT
M;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E
M<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(
M86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL
M:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!
M.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!
M4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I
M<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U
M=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN
M,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R
M97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER
M92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!0
M97)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I
M<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@
M)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@
M>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@
M*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)
M4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT
M('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A
M=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`]
M(&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F
M5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G
M:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@
M/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]
M('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*;7D@)'-T;7!D:7(@/2`B
M)'!A=&@D<WES>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE
M*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FUY("1C86-H95]D:7(["FEF("@D
M14Y6>U!!4E]#3$5!3GTI('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*?0IE
M;'-E('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D:64@
M<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PII9B`H*&UY("1M86=I
M8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@D9F@I*2`^/2`P*2!["G-E96L@)&9H
M+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP
M0T%#2$4B*2P@,#L*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L(&QE;F=T:"@B
M7#!#04-(12(I.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L
M("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#
M04-(12(I"BT@)&-A8VAE7VYA;65?<VEZ92P@,#L*<F5A9"`D9F@L("1B=68L
M("1C86-H95]N86UE7W-I>F4["B1B=68@/7X@<R]<,"\O9SL*)&-A8VAE7V1I
M<B`](")C86-H92TD8G5F(CL*?0I]"F-L;W-E("1F:#L*?0II9B`H(21C86-H
M95]D:7(I('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*)$5.5GM005)?0TQ%
M04Y](#T@,3L*?0HD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U])&-A8VAE7V1I
M<B(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PHD14Y6>U!!4E]414U0?2`]("1S
M=&UP9&ER.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%
M35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]S879E
M7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D
M9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L
M;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["FUY("1F
M:#L**&]P96X@)&9H+"`G/CIR87<G+"`D=&5M<&YA;64I"B8F("AP<FEN="`D
M9F@@)&-O;G1E;G1S*0HF)B`H8VQO<V4@)&9H*0IO<B!D:64@<7%;17)R;W(@
M=W)I=&EN9R`B)'1E;7!N86UE(CH@)"%=.PIC:&UO9"`D;6]D92P@)'1E;7!N
M86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL
M;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M
M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%2
M7U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@
M>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.
M5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-
M4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN
M9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.
M5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L
M:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I
M('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921S>7-[
M7V5X97TB*2!["B1P<F]G;F%M92`N/2`D<WES>U]E>&5].PIR971U<FX["GT*
M?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421S>7-[<&%T:%]S97!]7$4O
M+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!]
M(&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D<WES
M>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM
M?21P<F]G;F%M921S>7-[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D<WES
M>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](CL**"@D<')O9VYA;64@/2`B
M)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I
M<B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M
M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF
M("AI;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/"`P*2!["B1P<F]G
M;F%M92`]("(N)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@
M*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E
M9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W
M9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D
M<WES>U]D96QI;7U<12DO)'!W9"1S>7-[7V1E;&EM?2\["B1%3E9[4$%27U!2
M3T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF
M("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI]
M(&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H
M(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@
M>PID96QE=&4@)$5.5GLB4$%27R1?(GT["GT*9F]R("AQ=R\@5$U01$E2(%1%
M35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R)005)?)%\B?2`]("1%3E9[(E!!
M4E]'3$]"04Q?)%\B?2!I9B!E>&ES=',@)$5.5GLB4$%27T=,3T)!3%\D7R)]
M.PI]"FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%
M04Y].PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO
M9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`
M7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H
M($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL
M('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI
M8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@
M;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?
M<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L.B!#
M86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I
M;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P
M<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<
M*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@
M:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]4
M2U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T52
M4D]2.PHQ.PI?7T5.1%]?"@!P97)L>'-I+F,``````````$-!0TA%``")J\WO
M``````$;`SOL````'````#"/__\0!@``N)#__P0!``!ND?__&`$``!"2__]\
M`0``:I+__Z@!``"$D___"`(``#B5__]H`@``!);__Z@"``!>EO__S`(``(:6
M___@`@``,I?__Q@#```TE___+`,``-J8__]X`P``_)C__Y@#``#<F?__W`,`
M`%R=__\,!```JIW__S`$``#RG?__2`0``.R>__^,!````I___Z@$``#"G___
M_`0``(RD__^0!0``.J;__\@%``#>IO__2`8``'Z[__]\!@``U+O__YP&``#(
MO/__X`8``'R^__\@!P```````!```````````WI2``%\`0$;#`(`$````!@`
M``"LC___(@`````'`0!@````+````$Z0__^B`````$(.0$Z!`H@$EA!2D@B3
M"I0,9HD&E0YFR4+20M-"U$+50L%$R$+60@X`0@Y`@0*(!(D&D@B3"I0,E0Z6
M$%#)U432T]1$D@B3"I0,0M)"TT+4````*````)````",D/__6@````!"#K`!
M1H@$B0:!`@)&"L%"R$+)0@X`0@L```!<````O````+J0__\:`0```$(.P`%$
MD@B!`EB(!$;(4,%"TD(.`$(.P`&!`H@$D@A"B09,DPH"0I0,`E;45`K(0LE"
MTT(+1I0,2,C)T]1(B`2)!I,*E`Q$T]1"R$+)``!<````'`$``'21__^T`0``
M`$(.8%"(!(D&D@B!`I,*E`R5#I80`M0*P4+(0LE"TD+30M1"U4+60@X`0@MN
MEQ*8%`)<"M="V$0+5-?81)<2F!1&U]A$EQ*8%$;70M@````\````?`$``,B2
M___,`````$(.4$2(!%0.T"")!I((DPJ4#($"E0X"<@H.4$+!0LA"R4+20M-"
MU$+50@X`0@L`(````+P!``!4D___6@````!"#A!"B`1*@0)HR$+!7@X`````
M$````.`!``"*D___*``````````T````]`$``)Z3__^L`````$(.4%0.T$"!
M`H@$B0:2"),*`H(*#E!"P43(0LE"TD+30@X`0@L``!`````L`@``$I3__P(`
M````````2````$`"````E/__I@$```!"#N`!7@[@(8@$B0:2")80@0*3"I0,
ME0Z7$I@4`EP*#N`!0L%"R$+)0M)"TT+40M5"UD+70MA"#@!""QP```",`@``
M6I7__R(`````0@X02(@$@0)0R$+!0@X`0````*P"``!<E?__X`````!"#C!2
M#K`@D@B!`H@$B08"A@H.,$+!0LA"R4+20@X`0@M6"@XP0L%"R$+)0M)*#@!$
M"P`L````\`(``/B5__^``P```$(.,$B(!(D&D@B!`@,V`PK(0L%"R4+24@X`
M1`L````@````(`,``$B9__].`````$(.($2(!($">@K!0LA"#@!""P`4````
M1`,``'*9__](`````$(.8$*!$@!`````7`,``**9___Z`````$(.4%H.T(`$
MD@B3"I0,@0*(!(D&E0Z6$`*B"@Y00L%"R$+)0M)"TT+40M5"UD(.`$(+`!@`
M``"@`P``6)K__Q8`````0@X00H$"3L%"#@!0````O`,``%*:___``````$(.
M0$:)!I((@0)HB`1&R%C!0LE"TD(.`$0.0($"B`2)!I((1),*`D+(0M-"P4+)
M0M)*#@!$#D"!`HD&D@A$B`23"@"0````$`0``+Z:___*!````$X.D`->D@B3
M"I0,@0*(!`)LB0:5#@,X`0K!0LA"U4+20M-"U$3)0@X`0@L"7)803-9BR=56
MR$+!0M)"TT+40@X`1`Z0`X$"B`2)!I((DPJ4#)4.EA!,EQ)&UD+70I80EQ(#
M+`$*UD+70@L#X`#6UT26$)<21,G5UM=(B0:5#I80EQ(`-````*0$``#TGO__
MK@$```!"#D!"B`12D@B3"H$"B0:4#`-&`0K!0LA"R4+20M-"U$(.`$(+``!$
M````W`0``&J@__^D`````$(.,$:(!(D&@0("0@K!0LA"R4(.`$(+1)((;`K2
M0@M,R$+20L%$R4(.`$0.,($"B`2)!D*2"``T````)`4``!B)__^(`0```$(.
M8$R!`HD&B`22"),*`PP!"L%"R$+)0M-$TD(.`$(+`````````#````!<!0``
MCJ#__Z`4````1`[`!6"!`H@$B0:2"),*`V(4"L%$R$3)1-)$TT0.`$(+```<
M````D`4``/JT__]6`````$(.$$:!`@)*P4(.`````$````"P!0``,+7___0`
M````0@Y05(D&D@B4#)4.@0*(!),*=I801I<2`D+60M=0"L%"R$+)0M)"TT+4
M0M5"#@!""P``/````/0%``#@M?__M`$```!"#D!0B`2)!I,*E`R6$($"D@B5
M#@-0`0K(0L%"R4+20M-"U$+50M9"#@!$"P```!`````T!@``5+?__PP`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````0``````
M``#F`@````````$`````````]@(````````!```````````#````````(```
M``````"@JP```````"$`````````"``````````9`````````*BK````````
M&P`````````(`````````!H`````````L*L````````<``````````@`````
M````]?[_;P````#8`@````````4`````````*`T````````&`````````,@#
M````````"@````````"J!`````````L`````````&``````````5````````
M`````````````P````````#(K0````````(`````````0`4````````4````
M``````<`````````%P`````````0%0````````<``````````!,````````(
M`````````%`'````````"0`````````8`````````!X`````````"```````
M``#[__]O``````$```@`````_O__;P````"@$@```````/___V\``````@``
M``````#P__]O`````-(1````````^?__;P`````+````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````__________\``````````%`:
M````````4!H```````!0&@```````%`:````````4!H```````!0&@``````
M`%`:````````4!H```````!0&@```````%`:````````4!H```````!0&@``
M`````%`:````````4!H```````!0&@```````%`:````````4!H```````!0
M&@```````%`:````````4!H```````!0&@```````%`:````````4!H`````
M``!0&@```````%`:````````4!H```````!0&@```````%`:````````4!H`
M``````!0&@```````%`:````````4!H```````!0&@```````%`:````````
M4!H```````!0&@```````%`:````````4!H```````!0&@```````%`:````
M````4!H```````!0&@```````%`:````````4!H```````!0&@```````%`:
M````````4!H```````!0&@```````%`:````````4!H```````!0&@``````
M`%`:````````4!H```````!0&@```````%`:````````4!H```````"XJP``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````"E!!4BYP;0H`````````````````````````
M````````````````````````````````````````````````````````````
M1T-#.B`H1&5B:6%N(#$T+C(N,"TV*2`Q-"XR+C``064```!R:7-C=@`!6P``
M``00!7)V-C1I,G`Q7VTR<#!?83)P,5]F,G`R7V0R<#)?8S)P,%]Z:6-S<C)P
M,%]Z:69E;F-E:3)P,%]Z;6UU;#%P,%]Z86%M;S%P,%]Z86QR<V,Q<#```"YS
M:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YB=6EL9"UI9``N;F]T92Y!0DDM
M=&%G`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG
M;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L82YP;'0`+G1E>'0`+G)O9&%T
M80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N<')E:6YI=%]A<G)A>0`N:6YI
M=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N9V]T`"YD871A`"YB<W,`
M+F-O;6UE;G0`+G)I<V-V+F%T=')I8G5T97,`````````````````````````
M````````````````````````````````````````````````````````````
M````````"P````$````"`````````'`"````````<`(````````A````````
M`````````````0```````````````````!,````'`````@````````"4`@``
M`````)0"````````)`````````````````````0````````````````````F
M````!P````(`````````N`(```````"X`@```````"``````````````````
M```$````````````````````-````/;__V\"`````````-@"````````V`(`
M``````#L``````````4`````````"````````````````````#X````+````
M`@````````#(`P```````,@#````````8`D````````&`````@````@`````
M````&`````````!&`````P````(`````````*`T````````H#0```````*H$
M```````````````````!````````````````````3@```/___V\"````````
M`-(1````````TA$```````#(``````````4``````````@`````````"````
M`````%L```#^__]O`@````````"@$@```````*`2````````8``````````&
M`````@````@```````````````````!J````!`````(``````````!,`````
M````$P```````!`"````````!0`````````(`````````!@`````````=```
M``0```!"`````````!`5````````$!4```````!`!0````````4````4````
M"``````````8`````````'D````!````!@````````!0&@```````%`:````
M````H`,``````````````````!``````````$`````````!^`````0````8`
M````````\!T```````#P'0```````%@O```````````````````$````````
M````````````A`````$````"`````````$A-````````2$T```````!X00``
M````````````````"````````````````````(P````!`````@````````#`
MC@```````,".````````[`````````````````````0`````````````````
M``":`````0````(`````````L(\```````"PCP```````$@&````````````
M```````(````````````````````I````!`````#`````````*"K````````
MH)L````````(`````````````````````0`````````(`````````+,````.
M`````P````````"HJP```````*B;````````"`````````````````````@`
M````````"`````````"_````#P````,`````````L*L```````"PFP``````
M``@````````````````````(``````````@`````````RP````8````#````
M`````+BK````````N)L````````0`@````````8`````````"``````````0
M`````````-0````!`````P````````#(K0```````,B=````````.`(`````
M``````````````@`````````"`````````#9`````0````,``````````+``
M````````H````````%`````````````````````(````````````````````
MWP````@````#`````````%"P````````4*`````````H````````````````
M````"````````````````````.0````!````,````````````````````%"@
M````````'@````````````````````$``````````0````````#M`````P``
M<`````````````````````!NH````````&8````````````````````!````
M`````````````````0````,`````````````````````````U*````````#_
?`````````````````````0``````````````````````
